from django.test import TestCase
from ..save import Save


class SaveTestCase(TestCase):
    def setUp(self):
        """
        Create objects here...

        Example:
        Save.objects.create()
        """

        pass

    def test_create_save(self):
        """
        Run assertions here...

        Example:
        save = Save.objects.create()
        self.assertEqual(save.id, 1)
        """

        pass
