from django.test import TestCase
from ..models.file import File


class FileTestCase(TestCase):
    def setUp(self):
        """
        Create objects here...

        Example:
        File.objects.create()
        """
        pass

    def test_create_file(self):
        """
        Run assertions here...

        Example:
        file = File.objects.create()
        self.assertEqual(file.id, 1)
        """
        pass
