from django.test import TestCase
from ..image import Image


class ImageTestCase(TestCase):
    def setUp(self):
        """
        Create objects here...

        Example:
        Image.objects.create()
        """

        pass

    def test_create_image(self):
        """
        Run assertions here...

        Example:
        image = Image.objects.create()
        self.assertEqual(image.id, 1)
        """

        pass
