# Generated by Django 2.2.14 on 2020-07-30 19:13

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('arvestust', '0006_auto_20200730_1513'),
    ]

    operations = [
        migrations.AlterUniqueTogether(
            name='tag',
            unique_together=set(),
        ),
    ]
