from django.test import TestCase
from ..models.comment import Comment


class CommentTestCase(TestCase):
    def setUp(self):
        """
        Create objects here...

        Example:
        Comment.objects.create()
        """
        pass

    def test_create_comment(self):
        """
        Run assertions here...

        Example:
        comment = Comment.objects.create()
        self.assertEqual(comment.id, 1)
        """
        pass
