{% extends 'arvestust.html' %}
{% load cache %}

{% comment %}
    Describe the template here.
{% endcomment %}

{% block body %}
    <h2>{{ object }}</h2>
{% endblock body %}

{% block scripts %}{% endblock scripts %}

