{% extends 'arvestust.html' %}
{% load cache %}

{% comment %}
    Describe the template here.
{% endcomment %}

{% block header %}{% endblock header %}
{% block body %}

    <h2>images</h2>

    <ul>
    {% for object in object_list %}
    <li>
        <a href="{{ object.get_absolute_url }}">{{ object }}</a>
    </li>
    {% endfor %}
    </ul>
{% endblock body %}

{% block footer %}{% endblock footer %}

{% block scripts %}{% endblock scripts %}
