# Generated by Django 2.2.13 on 2020-08-03 20:19

import arvestust.models.abstracts.file
import arvestust.models.image
import arvestust.models.validators.file
from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('arvestust', '0010_auto_20200803_0050'),
    ]

    operations = [
        migrations.AddField(
            model_name='image',
            name='is_private',
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name='image',
            name='mime',
            field=models.CharField(blank=True, editable=False, max_length=100),
        ),
        migrations.AddField(
            model_name='image',
            name='name',
            field=models.CharField(blank=True, max_length=50),
        ),
        migrations.AddField(
            model_name='image',
            name='uploaded_by',
            field=models.ForeignKey(blank=True, editable=False, null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='image', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AlterField(
            model_name='file',
            name='file',
            field=models.FileField(storage='packager.storage.PublicFileStorage', upload_to=arvestust.models.abstracts.file.file_upload_path, validators=[arvestust.models.validators.file.validate_file_size, arvestust.models.validators.file.validate_file_type], verbose_name='file'),
        ),
        migrations.AlterField(
            model_name='image',
            name='file',
            field=models.ImageField(storage='packager.storage.PublicFileStorage', upload_to=arvestust.models.image.file_upload_path, validators=[arvestust.models.validators.file.validate_file_size], verbose_name='file'),
        ),
    ]
