from django.test import TestCase
from ..models.like import Like


class LikeTestCase(TestCase):
    def setUp(self):
        """
        Create objects here...

        Example:
        Like.objects.create()
        """

        pass

    def test_create_like(self):
        """
        Run assertions here...

        Example:
        like = Like.objects.create()
        self.assertEqual(like.id, 1)
        """

        pass
