from django.test import TestCase
from ..models.tag import Tag


class TagTestCase(TestCase):
    def setUp(self):
        """
        Create objects here...

        Example:
        Tag.objects.create()
        """

        pass

    def test_create_tag(self):
        """
        Run assertions here...

        Example:
        tag = Tag.objects.create()
        self.assertEqual(tag.id, 1)
        """

        pass
