# Generated by Django 2.2.14 on 2020-07-30 19:16

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('contenttypes', '0002_remove_content_type_name'),
        ('arvestust', '0007_auto_20200730_1513'),
    ]

    operations = [
        migrations.AlterField(
            model_name='tag',
            name='content',
            field=models.CharField(max_length=64, verbose_name='content'),
        ),
        migrations.AlterUniqueTogether(
            name='tag',
            unique_together={('object_id', 'content_type', 'content')},
        ),
    ]
