from django.test import TestCase
from ..models.follow import Follow


class FollowTestCase(TestCase):
    def setUp(self):
        """
        Create objects here...

        Example:
        Follow.objects.create()
        """

        pass

    def test_create_follow(self):
        """
        Run assertions here...

        Example:
        follow = Follow.objects.create()
        self.assertEqual(follow.id, 1)
        """

        pass
