{% extends 'arvestust.html' %}
{% load cache %}

{% comment %}
    Describe the template here.
{% endcomment %}

{% block content %}
<div class="container">
    <h2 class="text-bold">comments</h2>

    <div class="row">
        {% for object in object_list %}
        <div class="col-md-12">
            <a href="{{ object.get_absolute_url }}">{{ object.content }}</a>
        </div>
        {% endfor %}
    </div>
</div>
{% endblock content %}
