# Generated by Django 2.2.13 on 2020-07-29 16:53

from django.conf import settings
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('arvestust', '0002_auto_20200729_1639'),
    ]

    operations = [
        migrations.AlterUniqueTogether(
            name='follow',
            unique_together={('object_id', 'user')},
        ),
        migrations.AlterUniqueTogether(
            name='like',
            unique_together={('object_id', 'user')},
        ),
        migrations.AlterUniqueTogether(
            name='save',
            unique_together={('object_id', 'user')},
        ),
        migrations.AlterUniqueTogether(
            name='tag',
            unique_together={('object_id', 'content')},
        ),
    ]
